==> abasic_0_0_6_8.zip: abasic_0_0_6_8/ap_if.cpp <==
/*
 * aBasic
 * Copyright (C) 2007 m_inaba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
//lXC++AvP[VɃC^v^gݍނ߂̃\[X


#include "./ap_if.h"
#include "./basic.h"

HANDLE     ap_if_hIOMutex = CreateMutex (NULL, FALSE, NULL);//Xbh΍
static char str_pos[MAX_STR_LEN+1];

//C^v^̏
volatile int basic_init(){
	int result;
	WaitForSingleObject( ap_if_hIOMutex, INFINITE );
	result=basic_init("main.txt");
	basic_setup();
	ReleaseMutex( ap_if_hIOMutex);
	return result;
}

//C^v^擪s
volatile void basic_run(){
	WaitForSingleObject( ap_if_hIOMutex, INFINITE );
	basic_start(1);
	ReleaseMutex( ap_if_hIOMutex);
}

//Tu[`̎s x̍ss
volatile int basic_goto(char*label){
	WaitForSingleObject( ap_if_hIOMutex, INFINITE );
	int resolt=0;
	unsigned int p_cont=0;
	if(p_cont=(unsigned int)getVariableVal(label)){
			basic_start(p_cont+1);
			resolt=1;//goto
	}
	ReleaseMutex( ap_if_hIOMutex);
	return resolt;
}

//֐̎s
volatile int basic_func(char*label){
	WaitForSingleObject( ap_if_hIOMutex, INFINITE );
	int resolt=0;
	unsigned char flag=0x80;
	p_counter=0;
	instcpy(str_pos,label);
	resolt=func_(str_pos,&source,&p_counter,&flag);
	basic_start(0);
	ReleaseMutex( ap_if_hIOMutex);
	return resolt;
}

//ϐɒlݒ肷
volatile void basic_setVari(char*name,char*val){
	WaitForSingleObject( ap_if_hIOMutex, INFINITE );
	//Sĕ^Ƃ
	char*str_ptr=str_pos+1;
	_strcpy(str_ptr,val);
	str_ptr--;
	*str_ptr='\"';
	setVariableStr(name,str_ptr);
	ReleaseMutex( ap_if_hIOMutex);
}

//ϐ̒l擾
volatile char* basic_getVari(char*name){
	WaitForSingleObject( ap_if_hIOMutex, INFINITE );
	char*resolt;
	_strcpy(str_pos,getVariableStr(name));
	if('\"'==*str_pos){
		resolt=str_pos+1;
	}else {
		resolt=str_pos;
	}
	ReleaseMutex( ap_if_hIOMutex);
	return resolt;
}


//-------------------------------------------------------------------------------

==> abasic_0_0_6_9.zip: abasic_0_0_6_9/ap_if.cpp <==
//-------------------------------------------------------------------------------
// ap_if.cpp
//-------------------------------------------------------------------------------

//lXC++AvP[VɃC^v^gݍނ߂̃\[X


#include "./ap_if.h"
#include "./basic.h"

HANDLE     ap_if_hIOMutex = CreateMutex (NULL, FALSE, NULL);//Xbh΍
static char str_pos[MAX_STR_LEN+1];

//C^v^̏
volatile int basic_init(){
	int result;
	WaitForSingleObject( ap_if_hIOMutex, INFINITE );
	result=basic_init("main.txt");
	basic_setup();
	ReleaseMutex( ap_if_hIOMutex);
	return result;
}

//C^v^擪s
volatile void basic_run(){
	WaitForSingleObject( ap_if_hIOMutex, INFINITE );
	basic_start(1);
	ReleaseMutex( ap_if_hIOMutex);
}

//Tu[`̎s x̍ss
volatile int basic_goto(char*label){
	WaitForSingleObject( ap_if_hIOMutex, INFINITE );
	int resolt=0;
	unsigned int p_cont=0;
	if(p_cont=(unsigned int)getVariableVal(label)){
			basic_start(p_cont+1);
			resolt=1;//goto
	}
	ReleaseMutex( ap_if_hIOMutex);
	return resolt;
}

//֐̎s
volatile int basic_func(char*label){
	WaitForSingleObject( ap_if_hIOMutex, INFINITE );
	int resolt=0;
	unsigned char flag=0x80;
	p_counter=0;
	instcpy(str_pos,label);
	resolt=func_(str_pos,&source,&p_counter,&flag);
	basic_start(0);
	ReleaseMutex( ap_if_hIOMutex);
	return resolt;
}

//ϐɒlݒ肷
//߂lɓ̕ϐ(char)̃|C^Ԃ
volatile char* basic_setVari(char*name,char*val){
	WaitForSingleObject( ap_if_hIOMutex, INFINITE );
	//Sĕ^Ƃ
	char*str_ptr=str_pos+1;
	_strcpy(str_ptr,val);
	str_ptr--;
	*str_ptr='\"';
	//߂l͕Kchar*^ł
	char*resolt=setVariable(name,str_ptr);
	ReleaseMutex( ap_if_hIOMutex);
	return resolt+1;
}

//ϐ̒l擾
volatile char* basic_getVari(char*name){
	WaitForSingleObject( ap_if_hIOMutex, INFINITE );
	char*resolt;
	_strcpy(str_pos,getVariableStr(name));
	if('\"'==*str_pos){
		resolt=str_pos+1;
	}else {
		resolt=str_pos;
	}
	ReleaseMutex( ap_if_hIOMutex);
	return resolt;
}

//-------------------------------------------------------------------------------
